ghcnd_search, to add a column giving the variable name
(key) and change the name of the variable column to value.
These changes facilitate combining all elements from the list created by
ghcnd_search, to create a tidy dataframe of the weather
observations from the station.
meteo_tidy_ghcnd_element(x, keep_flags = FALSE)ghcnd_search.