rnoaa-package: General purpose R interface to noaa.
Description
rnoaa is an R interface to NOAA climate data.Details
Many functions in this package interact with the National Climatic Data Center application
programming interface (API) at http://www.ncdc.noaa.gov/cdo-web/webservices/v2, all of
which functions start with ncdc_. An access token, or API key, is required to use all
the ncdc_ functions. The key is required by NOAA, not the creators of this R package.
Go to the link given above to get an API key. More NOAA data sources are being added through time. Data sources and their function prefixes
are:
-
buoy_* - NOAA Buoy data, only on buoy branch in Github repo
-
erddap_* - NOAA ERDDAP vignette
-
ncdc_* - NOAA National Climatic Data Center (NCDC) vignette (examples)
-
seaice - Sea ice vignette
-
swdi - Severe Weather Data Inventory (SWDI) vignette
-
homr_* - Historical Observing Metadata Repository (HOMR) vignette
-
storm_ - Storms (IBTrACS) vignette
-
tornadoes - From the NOAA Storm Prediction Center